package cn.com.qmth.export;

import java.io.File;
import java.io.IOException;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.HashSet;
import java.util.LinkedHashSet;
import java.util.Map;
import java.util.Set;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

public class MyProducer extends Producer {
	private static Logger logger = LogManager.getLogger(MyProducer.class);
	private static String dir = "d:/chuannong/";
	private static String paperDir = "d:/chuannong/paper/";

	@Override
	protected void produce(Map<String, Object> param) throws Exception {
		Connection connect = null;
		try {
			String dbName = (String) param.get("dbName");
			Class.forName("com.mysql.cj.jdbc.Driver");

			String url = "jdbc:mysql://localhost:3306/" + dbName + "?serverTimezone=GMT%2B8";

			String user = "root";

			String password = "123456";
			connect = DriverManager.getConnection(url, user, password);
			logger.info("***************************任务生产开始");
			Set<Integer> nestedQids = getNestedQids(connect);
			String paperSuff = (String) param.get("paperSuff");

			File excelFolder = new File(paperDir);
			if (excelFolder.exists()) {
				FileUtil.clearDirectory(paperDir);
			} else {
				excelFolder.mkdirs();
			}
			LinkedHashSet<String> cs = readSubject();
			if (CollectionUtils.isEmpty(cs)) {
				logger.debug("无数据导出");
				return;
			} else {
				logger.debug(cs.size() + "个课程");
			}
			for (String c : cs) {
				offer(new PaperExportDto(nestedQids, c, paperSuff, dbName));
			}
			logger.info("***************************任务生产结束");
		} catch (Exception e) {
			throw new RuntimeException(e);
		} finally {
			if (connect != null) {
				try {
					connect.close();
				} catch (SQLException e) {
				}
			}
		}

	}

	private Set<Integer> getNestedQids(Connection connect) throws SQLException, IOException {
		Set<Integer> ret = new HashSet<>();
		PreparedStatement preState = null;
		ResultSet resultSet = null;
		try {
			String sql = " select DISTINCT  q2.ParentQuesID id from Exam_e_QuestionInfo q2 where q2.ParentQuesID!=0 ";

			preState = connect.prepareStatement(sql);

			resultSet = preState.executeQuery();

			while (resultSet.next()) {
				ret.add(resultSet.getInt("id"));
			}
			return ret;
		} finally {
			if (resultSet != null) {
				resultSet.close();
			}
			if (preState != null) {
				preState.close();
			}
		}
	}

	private static LinkedHashSet<String> readSubject() {
		LinkedHashSet<String> list = new LinkedHashSet<>();
		XSSFWorkbook wb = null;
		try {
			wb = new XSSFWorkbook(dir + "subject_info.xlsx");
			XSSFSheet sheet = wb.getSheetAt(0);
			int rows = sheet.getLastRowNum();
			for (int i = 1; i <= rows; i++) {
				XSSFRow row = sheet.getRow(i);
				String yunkaiCode = row.getCell(1).getStringCellValue().trim();
				list.add(yunkaiCode);
			}
		} catch (IOException e) {
			throw new RuntimeException(e);
		} finally {
			if (wb != null) {
				try {
					wb.close();
				} catch (IOException e) {
				}
			}
		}
		return list;
	}
}
